<?php
/**
 * @package com_tinydoc for Joomla! 2.5
 * @version $Id: controller.php 2013-06-03 $
 * @author Andreas Thul
 * @copyright (c) 2009-2013 Andreas Thul
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
**/

defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.controller');
jimport('joomla.filesystem.file');
jimport('joomla.utilities.date');

class TinyDocController extends JController {

	function __construct() {

		parent::__construct();
		$this->registerTask('add', 'edit');
		$this->registerTask('unpublish', 'publish');
		$this->registerTask('gallery_unpublish', 'gallery_publish');
		$this->registerTask('unskip', 'skip');
	}

	// 2012-08-17: improved error handling
	function save() {

		$option = JRequest::getCmd('option');
		$this->setRedirect('index.php?option=' . $option);

		$post = JRequest::get('post');

		$row =& JTable::getInstance('Document', 'Table');

		if (!$row->bind($post) || !$row->store()) {
			return JError::raiseWarning(500, $row->getError());
		}

		// 2012-08-08: set initial value of ordering to id
		if ($row->ordering == null) { $row->ordering = $row->id; }

		$upload = JRequest::get('files');

		$error = 0;

		if (strlen($upload['document_upload']['name']) > 0) {

			if (!JFile::upload($upload['document_upload']['tmp_name'], TinyDocHelper::getDocumentFile($row->id))) {

				$this->setError( JText::_('Error uploading the file') );
				$row->delete();

				$error = 1;
			}
			else {

				$row->name = $upload['document_upload']['name'];
				$row->size = $upload['document_upload']['size'];
				$row->type_id = TinyDocHelper::getTypeID($upload['document_upload']['type']);
				// $row->type = $upload['document_upload']['type'];

				$now = new JDate();
				$row->date = $now->toFormat("%Y-%m-%d");

				if (!$row->store()) {
					return JError::raiseWarning(500, $row->getError());
				}
			}

		}

		if (! $error) { $this->setMessage(JText::_('MESSAGE_DOCUMENT_SAVED')); }
	}

	function saveFolder() {

		$option = JRequest::getCmd('option');
		$this->setRedirect('index.php?option=' . $option . '&task=listFolders');

		$post = JRequest::get('post');

		$row =& JTable::getInstance('Folder', 'Table');

		if (!$row->bind($post)) {
			return JError::raiseWarning(500, $row->getError());
		}

		if (!$row->store()) {
			return JError::raiseWarning(500, $row->getError());
		}

		$this->setMessage(JText::_('MESSAGE_FOLDER_SAVED'));
	}

	// 2013-06-03: Only variables should be assigned by reference
	function editDocument() {

		$cid = JRequest::getVar('cid', array(), 'request', 'array');

		$row = JTable::getInstance('Document', 'Table');

		if (isset($cid[0])) {
			$row->load($cid[0]);
		}

		$option = JRequest::getCmd('option');
		HTML_TinyDoc::edit($option, $row);
	}

	// 2013-06-03: Only variables should be assigned by reference
	function editFolder() {

		$cid = JRequest::getVar('cid', array(), 'request', 'array');

		$row = JTable::getInstance('Folder', 'Table');

		if (isset($cid[0])) {
			$row->load($cid[0]);
		}

		$option = JRequest::getCmd('option');
		HTML_TinyDoc::editFolder($option, $row);
	}

	function removeDocument() {

		$option = JRequest::getCmd('option');

		$this->setRedirect('index.php?option=' . $option);

		$db	=& JFactory::getDBO();
		$cid = JRequest::getVar('cid', array(), 'request', 'array');

		$count = count($cid);

		if ($count) {

			foreach ($cid as $id) {

				$db->setQuery('DELETE FROM #__tinydoc_document WHERE id = ' . $id );
				if (!$db->query()) { JError::raiseWarning( 500, $db->getError() ); }

				$file = TinyDocHelper::getDocumentFile($id);
				if (file_exists($file)) { unlink($file); }
				}

			$this->setMessage(JText::_('MESSAGE_DOCUMENT_DELETED'));
		}
	}

	function removeFolder() {

		$option = JRequest::getCmd('option');

		$this->setRedirect('index.php?option=' . $option . '&task=listFolders');

		$db	=& JFactory::getDBO();
		$cid = JRequest::getVar('cid', array(), 'request', 'array');

		$count = count($cid);

		if ($count) {

			foreach ($cid as $id) {

				$db->setQuery("SELECT count(*) FROM #__tinydoc_document WHERE folder_id = $id");
				if (!$db->query()) { JError::raiseWarning( 500, $db->getError() ); }
				$total = $db->loadResult();

				if ($total) {
					JError::raiseWarning( 500, "folder #$id not empty");
				}
				else {
					$db->setQuery('DELETE FROM #__tinydoc_folder WHERE id = ' . $id );
					if (!$db->query()) { JError::raiseWarning( 500, $db->getError() ); }

					$this->setMessage(JText::_('MESSAGE_FOLDER_DELETED'));

				}
			}
		}
	}

	function publish() {

		$option = JRequest::getCmd('option');

		$this->setRedirect('index.php?option=' . $option);

		$cid = JRequest::getVar('cid', array(), 'request', 'array');

		if ($this->getTask() == 'publish') { $publish = 1; }
		else { $publish = 0; }

		$table =& JTable::getInstance('Document', 'Table');

		$table->publish($cid, $publish);

		$this->setMessage(JText::_('MESSAGE_PUBLISHED_CHANGED'));
	}

	// 2012-08-08: added code for manual ordering
	// 2013-06-03: Only variables should be assigned by reference
	function listDocuments() {

		$mainframe = JFactory::getApplication();
		$option = JRequest::getCmd('option');

        $limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
        $limitstart = $mainframe->getUserStateFromRequest($option.'.limitstart', 'limitstart', 0, 'int');
		$search = $mainframe->getUserStateFromRequest($option.'search', 'search', '', 'string');

		$filter_state = $mainframe->getUserStateFromRequest($option.'filter_state', 'filter_state', '', 'word');
		$filter_folder_id = $mainframe->getUserStateFromRequest($option.'filter_folder_id',	'filter_folder_id', 0, 'int');
		$filter_type_id = $mainframe->getUserStateFromRequest($option.'filter_type_id',	'filter_type_id', 0, 'int');

		$filter_order		= $mainframe->getUserStateFromRequest($option.'filter_order',		'filter_order',		'id',	'cmd' );
		$filter_order_Dir	= $mainframe->getUserStateFromRequest($option.'filter_order_Dir',	'filter_order_Dir',	'',			'word' );

		$lists['search'] = $search;

		$db	= JFactory::getDBO();

		if (strlen($search) > 0) { $search = " WHERE description LIKE '%$search%' "; }

		if ($filter_folder_id) {

			if (strlen($search) > 0) { $search .= " AND folder_id = $filter_folder_id "; }
			else { $search = " WHERE folder_id = $filter_folder_id "; }
		}

		if ($filter_type_id) {

			if (strlen($search) > 0) { $search .= " AND type_id = $filter_type_id "; }
			else { $search = " WHERE type_id = $filter_type_id "; }
		}

		if ($filter_state) {
			if ($filter_state == 'P') {
				$filter .= 'published = 1';
			}
			elseif ($filter_state == 'U') {
				$filter .= 'published = 0';
			}

			if (strlen($search) > 0) { $search .= " AND $filter "; }
			else { $search = " WHERE $filter "; }
		}

		// sanitize $filter_order
		if (!in_array($filter_order, array('name', 'description', 'date', 'size', 'ordering', 'id'))) {
			$filter_order = 'name';
		}

		if (!in_array(strtoupper($filter_order_Dir), array('ASC', 'DESC'))) {
			$filter_order_Dir = '';
		}
		$orderby	= ' ORDER BY ' . $filter_order . ' ' . $filter_order_Dir . ', ordering';

		$db->setQuery("SELECT count(*) FROM #__tinydoc_document $search");
		if (!$db->query()) { JError::raiseWarning( 500, $db->getError() ); }
		$total = $db->loadResult();

		$db->setQuery("SELECT * FROM #__tinydoc_document $search $orderby", $limitstart, $limit);
		if (!$db->query()) { JError::raiseWarning( 500, $db->getError() ); }
		$rows = $db->loadObjectList();

		jimport('joomla.html.pagination');
		$pageNav = new JPagination($total, $limitstart, $limit);

		$javascript 	= 'onchange="document.adminForm.submit();"';
		$lists['folder_id'] = TinyDocHelper::selectFolder('filter_folder_id', $option, intval($filter_folder_id), $javascript);
		$lists['type_id'] = TinyDocHelper::selectType('filter_type_id', $option, intval($filter_type_id), $javascript);
		$lists['state']	= JHTML::_('grid.state',  $filter_state );

		// table ordering
		$lists['order_Dir']	= $filter_order_Dir;
		$lists['order']		= $filter_order;

		HTML_TinyDoc::listDocuments($option, $rows, $pageNav, $lists);
	}

	// 2013-06-03: Only variables should be assigned by reference
	function listFolders() {

		$mainframe = JFactory::getApplication();
		$option = JRequest::getCmd('option');

        $limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
        $limitstart = $mainframe->getUserStateFromRequest($option.'.limitstart', 'limitstart', 0, 'int');
		$search = $mainframe->getUserStateFromRequest( $option.'search', 'search', '', 'string');

		$db	= JFactory::getDBO();

		$db->setQuery("SELECT count(*) FROM #__tinydoc_folder");
		if (!$db->query()) { JError::raiseWarning( 500, $db->getError() ); }
		$total = $db->loadResult();

		$db->setQuery("SELECT * FROM #__tinydoc_folder ORDER BY name ASC");
		if (!$db->query()) { JError::raiseWarning( 500, $db->getError() ); }
		$rows = $db->loadObjectList();

		jimport('joomla.html.pagination');
		$pageNav = new JPagination($total, $limitstart, $limit);

		HTML_TinyDoc::listFolders($option, $rows, $pageNav);
	}

	// 2013-06-03: Only variables should be assigned by reference
	function listTypes() {

		$mainframe = JFactory::getApplication();
		$option = JRequest::getCmd('option');

        $limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
        $limitstart = $mainframe->getUserStateFromRequest($option.'.limitstart', 'limitstart', 0, 'int');
		$search = $mainframe->getUserStateFromRequest( $option.'search', 'search', '', 'string');

		$db	= JFactory::getDBO();

		$db->setQuery("SELECT count(*) FROM #__tinydoc_type");
		if (!$db->query()) { JError::raiseWarning( 500, $db->getError() ); }
		$total = $db->loadResult();

		$db->setQuery("SELECT * FROM #__tinydoc_type ORDER BY type ASC");
		if (!$db->query()) { JError::raiseWarning( 500, $db->getError() ); }
		$rows = $db->loadObjectList();

		jimport('joomla.html.pagination');
		$pageNav = new JPagination($total, $limitstart, $limit);

		HTML_TinyDoc::listTypes($option, $rows, $pageNav);
	}

	function showAbout() {

		// 2013-06-03: Only variables should be assigned by reference
		$mainframe = JFactory::getApplication();
		$option = JRequest::getCmd('option');

		if (! $xmldata = JApplicationHelper::parseXMLInstallFile(JPATH_COMPONENT.DS . 'tinydoc.xml')) {

			$xmldata['creationdate'] = 'unknown';
			$xmldata['version'] = 'unknown';
			$xmldata['description'] = 'none';
			$xmldata['name'] = 'none';
			$xmldata['license'] = 'none';
		}

		HTML_TinyDoc::about($xmldata);
	}

	function updateTypes() {

		$option = JRequest::getCmd('option');

		$this->setRedirect('index.php?option=' . $option . '&task=listTypes');

		$db	=& JFactory::getDBO();

		$post = JRequest::get('post');

		foreach ($post as $key => $value) {

			if (preg_match("/^__type_/", $key)) {

				$key = preg_replace("/^__type_/", "", $key);

				$db->setQuery("UPDATE #__tinydoc_type SET icon='$value' WHERE id = '$key';");
				if (!$db->query()) { JError::raiseWarning( 500, $db->getError() ); }
			}

		}
	}

	function saveOrder() {

		$option = JRequest::getCmd('option');
		$this->setRedirect('index.php?option=' . $option . '&task=listDocuments');

		// Initialize variables
		$db			=& JFactory::getDBO();
		$cid		= JRequest::getVar('cid', array(), 'post', 'array' );
		$order		= JRequest::getVar('order', array(), 'post', 'array' );
		$row		=& JTable::getInstance('document', 'Table');
		$total		= count($cid);
		$conditions	= array();

		if (empty( $cid )) {
			return JError::raiseWarning( 500, JText::_('No items selected') );
		}

		// update ordering values
		for ($i = 0; $i < $total; $i++)
		{
			$row->load((int) $cid[$i]);
			if ($row->ordering != $order[$i])
			{
				$row->ordering = $order[$i];
				if (!$row->store()) {
					return JError::raiseError( 500, $db->getErrorMsg() );
				}
			}
		}

		// Clear the component's cache
		$cache =& JFactory::getCache($option);
		$cache->clean();

		$this->setMessage(JText::_('New ordering saved'));
	}

	function orderup() {

		$option = JRequest::getCmd('option');
		$this->setRedirect('index.php?option=' . $option . '&task=listDocuments');

		$cid = JRequest::getVar('cid', array(0), '', 'array');
		$db =& JFactory::getDBO();

		// document to be moved down
		$id = $cid[0];
		$row=& JTable::getInstance('Document', 'Table');
		$row->load($id);

		// document to be swapped with
		$query = "SELECT id FROM #__tinydoc_document WHERE ordering < " . $row->ordering . " ORDER BY ordering DESC LIMIT 1";
		$db->setQuery($query);
		$tmp = $db->loadObject();

		$row2=& JTable::getInstance('Document', 'Table');
		$row2->load($tmp->id);

		$row_ordering = $row->ordering;
		$row2_ordering = $row2->ordering;

		$row->ordering = $row2_ordering;
		$row2->ordering = $row_ordering;

		if (!$row->store()) {
			return JError::raiseWarning(500, $row->getError());
		}
		if (!$row2->store()) {
			return JError::raiseWarning(500, $row->getError());
		}

		// Clear the component's cache
		$cache =& JFactory::getCache($option);
		$cache->clean();

		$this->setMessage(JText::_('New ordering saved'));

	}

  function orderdown() {

		$option = JRequest::getCmd('option');
		$this->setRedirect('index.php?option=' . $option . '&task=listDocuments');

		$cid = JRequest::getVar('cid', array(0), '', 'array');
		$db =& JFactory::getDBO();

		// document to be moved down
		$id = $cid[0];
		$row=& JTable::getInstance('Document', 'Table');
		$row->load($id);

		// document to be swapped with
		$query = "SELECT id FROM #__tinydoc_document WHERE ordering > " . $row->ordering . " ORDER BY ordering ASC LIMIT 1";
		$db->setQuery($query);
		$tmp = $db->loadObject();

		$row2=& JTable::getInstance('Document', 'Table');
		$row2->load($tmp->id);

		$row_ordering = $row->ordering;
		$row2_ordering = $row2->ordering;

		$row->ordering = $row2_ordering;
		$row2->ordering = $row_ordering;

		if (!$row->store()) {
			return JError::raiseWarning(500, $row->getError());
		}
		if (!$row2->store()) {
			return JError::raiseWarning(500, $row->getError());
		}

		// Clear the component's cache
		$cache =& JFactory::getCache($option);
		$cache->clean();

		$this->setMessage(JText::_('New ordering saved'));
  }


}

?>
