<?php
/**
 * @package com_tinydoc for Joomla! 2.5
 * @version $Id: helper.php 2014-01-16 $
 * @author Andreas Thul
 * @copyright (c) 2009-2012 Andreas Thul
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
**/

defined('_JEXEC') or die('Restricted access');

jimport('joomla.filesystem.file');

// 2013-06-03: changed all methods to static
class TinyDocHelper {

	static function cutText($buffer, $limit) {

		if (strlen($buffer) > $limit) {

			$chunksize = $limit / 2 - 5;
			$output = substr($buffer, 0, $chunksize) . ' ... ' . substr($buffer, strlen($buffer) - $chunksize, $chunksize);
		}
		else { $output = $buffer; }

	return $output;
	}

	// 2013-06-03: Only variables should be assigned by reference
	static function getFolderList() {

		$db	= JFactory::getDBO();

		$db->setQuery("SELECT * FROM #__tinydoc_folder ORDER BY name ASC");
		if (!$db->query()) { JError::raiseWarning( 500, $db->getError() ); }

		$folders[] = JHTML::_('select.option',  '0', '---', 'id', 'name');
        $folders = array_merge($folders, $db->loadObjectList());

		return $folders;
	}

	static function getIconList() {

		// 2012-07-09: added filter to recognize images only
		$icons = JFolder::files(JPATH_COMPONENT_SITE .DS. 'assets', '.gif$|.jpg$|.png$');

		return $icons;
	}

	static function getIconRadio($icons, $id, $current) {

		$buffer = '';

		foreach ($icons as $icon) {

			if ($icon == $current) { $checked = ' checked'; }
			else { $checked = ''; }

			# 2012-08-16: bugfix, JURI::root(true)
			$buffer .= "<input type=\"radio\" name=\"__type_$id\" value=\"$icon\" $checked onclick=\"document.adminForm.submit();\"><img src=\"" .  JURI::root(true) . "/components/com_tinydoc/assets/$icon\" />";

		}

		return $buffer;
	}

	// 2013-06-03: Only variables should be assigned by reference
	static function getFolderArray() {

		$db	= JFactory::getDBO();

		$db->setQuery("SELECT * FROM #__tinydoc_folder ORDER BY name ASC");
		if (!$db->query()) { JError::raiseWarning( 500, $db->getError() ); }
		$rows = $db->loadObjectList();

		$list = array();
		$list['0'] = '---';

		foreach ($rows as $row) {

			$list[$row->id] = $row->name;
		}

		return $list;
	}

	// 2013-06-03: Only variables should be assigned by reference
	static function getTypeArray() {

		$db	= JFactory::getDBO();

		$db->setQuery("SELECT * FROM #__tinydoc_type");
		if (!$db->query()) { JError::raiseWarning( 500, $db->getError() ); }
		$rows = $db->loadObjectList();

		$list = array();
		$list['0'] = '---';

		foreach ($rows as $row) {

			$list[$row->id] = $row->type;
		}

		return $list;
	}

	// 2013-06-03: Only variables should be assigned by reference
	static function getIconArray() {

		$db	= JFactory::getDBO();

		$db->setQuery("SELECT * FROM #__tinydoc_type");
		if (!$db->query()) { JError::raiseWarning( 500, $db->getError() ); }
		$rows = $db->loadObjectList();

		$list = array();
		$list['0'] = '---';

		foreach ($rows as $row) {

			$list[$row->id] = $row->icon;
		}

		return $list;
	}

	static function getDocumentFile($id) {

		return JPath::clean(JPATH_SITE .DS. 'tinydoc_documents' .DS. sprintf("%010d", $id));
	}

	// 2013-06-03: Only variables should be assigned by reference
    static function selectFolder($name, $section, $active = NULL, $javascript = NULL, $order = 'ordering', $size = 1, $sel_cat = 1 ) {

        $db = JFactory::getDBO();

        $query = 'SELECT id AS value, name AS text FROM #__tinydoc_folder';

        $db->setQuery( $query );
		if ($sel_cat) {
            $folders = array(JHTML::_('select.option',  '0', JText::_('SELECT_FOLDER')));
            $folders = array_merge( $folders, $db->loadObjectList() );
        } else {
            $folders = $db->loadObjectList();
        }

        $folder = JHTML::_('select.genericlist',   $folders, $name, 'class="inputbox" size="'. $size .'" '. $javascript, 'value', 'text', $active );
        return $folder;

    }

	// 2013-06-03: Only variables should be assigned by reference
    static function selectType($name, $section, $active = NULL, $javascript = NULL, $order = 'ordering', $size = 1, $sel_cat = 1 ) {

        $db = JFactory::getDBO();

        $query = 'SELECT id AS value, type AS text FROM #__tinydoc_type';

        $db->setQuery( $query );
		if ($sel_cat) {
            $folders = array(JHTML::_('select.option',  '0', JText::_('SELECT_TYPE')));
            $folders = array_merge( $folders, $db->loadObjectList() );
        } else {
            $folders = $db->loadObjectList();
        }

        $folder = JHTML::_('select.genericlist',   $folders, $name, 'class="inputbox" size="'. $size .'" '. $javascript, 'value', 'text', $active );
        return $folder;
    }

    static function getSizeAsText($size) {

		$kb = 1024;
		$mb = 1024 * 1024;
		$gb = 1024 * 1024 * 1024;

		if ($size > $gb) {
			$buffer = sprintf("%.2f GB", $size / $gb);
		}
		elseif ($size > $mb) {
			$buffer = sprintf("%.2f MB", $size / $mb);
		}
		elseif ($size > $kb) {
			$buffer = sprintf("%.2f KB", $size / $kb);
		}
		else {
			$buffer = sprintf("%.2f Bytes", $size);
		}

	return $buffer;
	}

	static function getTypeID($type) {

		$db	=& JFactory::getDBO();
		$db->setQuery("SELECT * FROM #__tinydoc_type WHERE type = '$type'");
		if (!$db->query()) { JError::raiseWarning( 500, $db->getError() ); }

		if (!($id = $db->loadResult())) {

			$config = &JComponentHelper::getParams('com_tinydoc');
			$icon = $config->get('default_icon', 'empty.gif');

			$typerow =& JTable::getInstance('Type', 'Table');
			$typerow->type = $type;
			$typerow->icon = $icon;

			if (!$typerow->store()) {
				return JError::raiseWarning(500, $typerow->getError());
			}

			$id = $typerow->id;
		}

	return $id;
	}

	// 2014-01-16: Only variables should be assigned by reference
	static function getDocumentType($id) {

		$db	= JFactory::getDBO();
		$db->setQuery("SELECT * FROM #__tinydoc_type WHERE id = $id");

		$type = $db->loadResult();

		return $type->type;
	}

}

?>
